==> ev_framework-3.0.2.tar.gz: lib/_FrameWork/Ev/_Image_Get.dart <==
import 'dart:io';
import 'package:ev_framework/_FrameWork/vSystem.dart';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'dart:async';

import '../vText.dart';
import '_ImageCrop_Page.dart';

final Map<String,PickedFile> pickefile = Map();
const  Map<String, String> $Image_camera = {'1': 'Camera', '2': '相機'};
const  Map<String, String> $Image_gallery = {'1': 'Gallery', '2': '圖片庫'};
const  Map<String, String> $Image_file = {'1': 'File', '2': '檔案'};


class $$Image_Get
{
  static Future<File> Get_From_Camera(BuildContext context,{double maxWidth=1200,double maxHeight=2000,double crop_ratio = 0})
  async
  {  final picker = ImagePicker();
     PickedFile file = await picker.getImage(source: ImageSource.camera, maxHeight: maxHeight, maxWidth: maxWidth);

    if (file != null) {
       var output_image = await _get_image(context,File(file.path),crop_ratio,maxWidth,maxHeight);
       return output_image;
     }
  }

  static Future<File> Get_File() async {
    FilePickerResult result = await FilePicker.platform.pickFiles();
    File file;
    if(result != null)
       {  file = File(result.files.single.path);
          return file;
       }
  }


  static Future<File> Get_From_Gallery(BuildContext context,{double maxWidth=1200,double maxHeight=2000,double crop_ratio = 0}) async
  { final picker = ImagePicker();
    PickedFile file= await picker.getImage(source: ImageSource.gallery, maxHeight: maxHeight, maxWidth: maxWidth);
    if (file != null) {
       if(kIsWeb)
        {  pickefile[file.path] = file; }
      var output_image = await _get_image(context,File(file.path),crop_ratio,maxWidth,maxHeight);
      return output_image;
    }
  }

  static Get_Select_Image(BuildContext c,{onReceived,double crop_ratio = 0,double maxWidth=1200,double maxHeight=2000})
  {  showModalBottomSheet(
      context: c,
      builder: (BuildContext context){
        return  Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            ListTile(
                leading: Icon(Icons.camera),
                title:vText($Image_camera[vSystem.Lang_id]),
                onTap: () async {
                  Navigator.pop(context);
                  Get_From_Camera(c,maxWidth:maxWidth,maxHeight:maxHeight,crop_ratio: crop_ratio).then((image){
                       if(onReceived!=null)
                          {  onReceived(image); }
                  });
                }
            ),
            ListTile(
                leading: new Icon(Icons.photo_library),
                title: vText($Image_gallery[vSystem.Lang_id]),
                onTap: () async
                {  Navigator.pop(context);
                   Get_From_Gallery(c,maxWidth:maxWidth,maxHeight:maxHeight,crop_ratio: crop_ratio).then((image){
                        if(onReceived!=null)
                           {  onReceived(image); }
                   });
                }
            ),
          ],
        );
      }
    );
  }

  static Get_Select_File(BuildContext c,onFile, {double maxImageWidth=1200,double maxImageHeight=2000})
  {  showModalBottomSheet(
      context: c,
      builder: (BuildContext context){
        return  Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            ListTile(
                leading: Icon(Icons.camera),
                title: vText($Image_camera[vSystem.Lang_id]),
                onTap: () {
                  Navigator.pop(context);
                  Get_From_Camera(c,maxWidth:maxImageWidth,maxHeight:maxImageHeight).then((value) {
                    onFile(value);
                  });

                }
            ),
            ListTile(
                leading: Icon(Icons.photo_library),
                title:vText($Image_gallery[vSystem.Lang_id]),
                onTap: () {
                  Navigator.pop(context);
                  Get_From_Gallery(c,maxWidth:maxImageWidth,maxHeight:maxImageHeight).then((value) {
                       onFile(value);
                  });
                }
            ),

            ListTile(
                leading: Icon(Icons.attach_file),
                title: vText($Image_file[vSystem.Lang_id]),
                onTap: () { Navigator.pop(context);
                      Get_File().then((value){ onFile(value);});
                  }
                )
          ],
        );
      }
    );
  }


  static Future<File> _get_image(BuildContext context,File image,double crop_ratio,maxwidth,maxheight) async {
    if(crop_ratio == 0 )
    {  return image; }
    else {
      File im =  await Navigator.push(context, MaterialPageRoute(builder: (context) => $$ImageCrop_Page(imagefile: image,cropradio: crop_ratio)));
      print("Crop image return : " + im.toString());
      return im;
    }
  }

  static Crop_Image(BuildContext context,File image,double crop_ratio)
  async {
    File im = await Navigator.push(context, MaterialPageRoute(
        builder: (context) =>
            $$ImageCrop_Page(imagefile: image, cropradio: crop_ratio)));
    print("Crop image return : " + im.toString());
    return im;
  }

}

==> ev_framework-3.0.4.tar.gz: lib/_FrameWork/Ev/_Image_Get.dart <==
import 'dart:io';
import 'package:ev_framework/_FrameWork/vSystem.dart';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'dart:async';

import '../vText.dart';
import '_ImageCrop_Page.dart';

final Map<String,PickedFile> pickefile = Map();
const  Map<String, String> $Image_camera = {'1': 'Camera', '2': '相機'};
const  Map<String, String> $Image_gallery = {'1': 'Gallery', '2': '圖片庫'};
const  Map<String, String> $Image_file = {'1': 'File', '2': '檔案'};


class $$Image_Get
{
  static Future<File> Get_From_Camera(BuildContext context,{double maxWidth=1200,double maxHeight=2000,double crop_ratio = 0})
  async
  {  final picker = ImagePicker();
     PickedFile file = await picker.getImage(source: ImageSource.camera, maxHeight: maxHeight, maxWidth: maxWidth);

    if (file != null) {
       var output_image = await _get_image(context,File(file.path),crop_ratio,maxWidth,maxHeight);
       return output_image;
     }
  }

  static Future<File> Get_File() async {
    FilePickerResult result = await FilePicker.platform.pickFiles();
    File file;
    if(result != null)
       {  file = File(result.files.single.path);
          return file;
       }
  }

  static Future<File> Get_From_Gallery(BuildContext context,{double maxWidth=1200,double maxHeight=2000,double crop_ratio = 0}) async
  { final picker = ImagePicker();
    PickedFile file= await picker.getImage(source: ImageSource.gallery, maxHeight: maxHeight, maxWidth: maxWidth);
    if (file != null) {
       if(kIsWeb)
        {  pickefile[file.path] = file; }
      var output_image = await _get_image(context,File(file.path),crop_ratio,maxWidth,maxHeight);
      return output_image;
    }
  }

  static Get_Select_Image(BuildContext c,{onReceived,double crop_ratio = 0,double maxWidth=1200,double maxHeight=2000})
  {  showModalBottomSheet(
      context: c,
      builder: (BuildContext context){
        return  Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            ListTile(
                leading: Icon(Icons.camera),
                title:vText($Image_camera[vSystem.Lang_id]),
                onTap: () async {
                  Navigator.pop(context);
                  Get_From_Camera(c,maxWidth:maxWidth,maxHeight:maxHeight,crop_ratio: crop_ratio).then((image){
                    if(onReceived!=null && image!=null)
                          {  onReceived(image); }
                  });
                }
            ),
            ListTile(
                leading: new Icon(Icons.photo_library),
                title: vText($Image_gallery[vSystem.Lang_id]),
                onTap: () async
                {  Navigator.pop(context);
                   Get_From_Gallery(c,maxWidth:maxWidth,maxHeight:maxHeight,crop_ratio: crop_ratio).then((image){
                        if(onReceived!=null && image!=null)
                           {  onReceived(image); }
                   });
                }
            ),
          ],
        );
      }
    );
  }

  static Get_Select_File(BuildContext c,onFile, {double maxImageWidth=1200,double maxImageHeight=2000})
  {  showModalBottomSheet(
      context: c,
      builder: (BuildContext context){
        return  Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            ListTile(
                leading: Icon(Icons.camera),
                title: vText($Image_camera[vSystem.Lang_id]),
                onTap: () {
                  Navigator.pop(context);
                  Get_From_Camera(c,maxWidth:maxImageWidth,maxHeight:maxImageHeight).then((value) {
                    if(onFile!=null && value!=null)
                    {  onFile(value); }

                  });

                }
            ),
            ListTile(
                leading: Icon(Icons.photo_library),
                title:vText($Image_gallery[vSystem.Lang_id]),
                onTap: () {
                  Navigator.pop(context);
                  Get_From_Gallery(c,maxWidth:maxImageWidth,maxHeight:maxImageHeight).then((value) {
                    if(onFile!=null && value!=null)
                    {  onFile(value); }
                  });
                }
            ),

            ListTile(
                leading: Icon(Icons.attach_file),
                title: vText($Image_file[vSystem.Lang_id]),
                onTap: () { Navigator.pop(context);
                      Get_File().then((value){
                        if(onFile!=null && value!=null)
                          {  onFile(value); }
                      });
                  }
                )
          ],
        );
      }
    );
  }


  static Future<File> _get_image(BuildContext context,File image,double crop_ratio,maxwidth,maxheight) async {
    if(crop_ratio == 0 )
    {  return image; }
    else {
      File im =  await Navigator.push(context, MaterialPageRoute(builder: (context) => $$ImageCrop_Page(imagefile: image,cropradio: crop_ratio)));
      print("Crop image return : " + im.toString());
      return im;
    }
  }

  static Crop_Image(BuildContext context,File image,double crop_ratio)
  async {
    File im = await Navigator.push(context, MaterialPageRoute(
        builder: (context) =>
            $$ImageCrop_Page(imagefile: image, cropradio: crop_ratio)));
    print("Crop image return : " + im.toString());
    return im;
  }

}
